@@ -2,11 +2,23 @@
 from __future__ import annotations
 
 from dataclasses import dataclass
-from typing import NamedTuple
+from typing import Any, NamedTuple
 
 from .utils import bytes_to_little_int, decode_byte_string
 
 
+class Change(NamedTuple):
+    """Helper for storing changes to attributes."""
+
+    attr: str
+    old_value: Any
+    new_value: Any
+
+    def __str__(self) -> str:
+        """Use str to format Change message."""
+        return f'{self.attr.replace("_", " ").title()} changed from "{self.old_value}" to "{self.new_value}"'
+
+
 class Colour(NamedTuple):
     """Simple helper for colour formatting."""
 
